@@ -10,10 +10,15 @@ class GetterData:
     """
     Основной класс обработчик и загрузчик данных
     """
+
     def __init__(self):
         self.connection = None
         self.connect_data = self.get_connect_data()
-        self.settings = self.read_settings()
+        try:
+            self.settings = self.read_settings()
+        except Exception:
+            print('Неудалось найти настроечный файл, пожалуйста создайте его прежде чем начать работу!')
+            exit()
 
     def read_settings(self):
         """
@@ -27,6 +32,32 @@ class GetterData:
             settings = json.load(file)
         return settings
 
+    def write_settings(self, prefix_login='', url='', cert_vault_tls='', cert_vault_key='', cert_vault_verify=''):
+        """
+        Функция создания файла настроек
+
+        Parameters
+        ------------
+            prefix_login: str
+                Префикс для логина (если не требуется добавьте поле и передайте пустую строку)
+            url: str
+                Url для подключения с использованием секретного токена
+            cert_vault_tls: str
+                Путь до секретного сертификата
+            cert_vault_key: str
+                Путь до ключа сертификата
+            cert_vault_verify: str
+                Путь до верификации сертификата
+        """
+        settings_to_json = {'prefix_login': prefix_login,
+                            'url': url,
+                            'cert_vault_tls': cert_vault_tls,
+                            'cert_vault_key': cert_vault_key,
+                            'cert_vault_verify': cert_vault_verify, }
+
+        with open('settings.json', 'w') as file:
+            json.dump(settings_to_json, file)
+
     def get_connect_data(self):
         """
         Функция для получения данных для подключения к базе
@@ -90,8 +121,9 @@ class GetterData:
         """
         if len(self.connect_data) > 0:
 
-            cli = hvac.Client(url= self.settings['url'],
-                              token=vault_token, cert=(self.settings["cert_vault_tls"], self.settings["cert_vault_key"]),
+            cli = hvac.Client(url=self.settings['url'],
+                              token=vault_token,
+                              cert=(self.settings["cert_vault_tls"], self.settings["cert_vault_key"]),
                               verify=self.settings["cert_vault_verify"])
             if cli.is_authenticated():
                 creds = cli.secrets.kv.v2.read_secret_version(mount_point=vault_secret_engine, path=vault_path).get(
